
#ifndef _C11_fi507_
#define _C11_fi507_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F555_2770(EIF_REFERENCE);
extern void EIF_Minit507(void);
extern EIF_INTEGER_32 F657_3248(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
